==> seoman_beta-0.3.2-py3-none-any.whl: seoman/utils/service_utils.py <==
from typing import Dict, Any, List

from .date_utils import create_date_range

from google.auth.exceptions import RefreshError

from .. import auth
from datetime import datetime, timedelta

from typer import confirm, secho, colors


def create_body_list(
    body: Dict[Any, Any],
    new_body: List[Dict[Any, Any]] = [],
    granularity: str = None,
) -> List[Dict[Any, Any]]:
    """
    Gets a body, and creates a new body from that.
    """
    dates = create_date_range(
        start=body.get("startDate"),
        end=body.get("endDate"),
        granularity=granularity,
    )
    if granularity is not None:

        if granularity in [
            "monday",
            "tuesday",
            "wednesday",
            "thursday",
            "friday",
            "saturday",
            "sunday",
            "weekends",
            "weekdays",
        ]:
            for idx in range(len(dates)):
                try:
                    """
                    If the detail level is low, medium or high
                    reduce end day by one to prevent duplications.
                    """
                    body.update({"startDate": dates[idx], "endDate": dates[idx + 1]})
                    new_body.append(body.copy())
                except IndexError:
                    pass

        else:
            for idx in range(len(dates)):
                try:
                    """
                    If the detail level is low, medium or high
                    reduce end day by one to prevent duplications.
                    """
                    body.update(
                        {
                            "startDate": dates[idx],
                            "endDate": (
                                datetime.strptime(dates[idx + 1], "%Y-%m-%d")
                                - timedelta(days=1)
                            ).strftime("%Y-%m-%d"),
                        }
                    )
                    new_body.append(body.copy())
                except IndexError:
                    pass
    else:
        for date in dates:
            body.update({"startDate": date, "endDate": date})
            new_body.append(body.copy())

    return new_body


def path_exists(filename: str) -> bool:
    """
    Checks for the given file path exists.
    """
    from pathlib import Path

    return Path(filename).exists()


def regenerate_credentials(method):
    """
    If query raises RefreshError(Expired token causes this.)
    It automatically regenerate credentials
    and runs the method again.
    """

    def run_query(*args, **kw):
        try:
            result = method(*args, **kw)
        except RefreshError:
            regen = (
                confirm(
                    "Your credentials has expired, do you want to regenerate them?",
                ),
            )

            if regen is True:
                auth.get_authenticated()
                secho(
                    "Authenticated successfully!",
                    fg=colors.BRIGHT_GREEN,
                    bold=True,
                ),
                result = method(*args, **kw)
            else:
                msg = secho(
                    "Aborting...",
                    bold=True,
                    fg=colors.BRIGHT_RED,
                )
                exit()

        return result

    return run_query

==> seoman_beta-0.35.0-py3-none-any.whl: seoman/utils/service_utils.py <==
from typing import Dict, Any, List

from .date_utils import create_date_range

from google.auth.exceptions import RefreshError  # type: ignore

from .. import auth
from datetime import datetime, timedelta

import typer


def create_body_list(
    body: Dict[Any, Any], new_body: List[Dict[Any, Any]] = [], granularity: str = None,
) -> List[Dict[Any, Any]]:
    """
    Gets a body, and creates a new body from that.
    """
    dates = create_date_range(
        start=body.get("startDate"), end=body.get("endDate"), granularity=granularity,
    )
    if granularity is not None:

        if granularity in [
            "monday",
            "tuesday",
            "wednesday",
            "thursday",
            "friday",
            "saturday",
            "sunday",
        ]:
            for idx in range(len(dates)):
                try:
                    """
                    If the detail level is low, medium or high
                    reduce end day by one to prevent duplications.
                    """
                    body.update({"startDate": dates[idx], "endDate": dates[idx]})
                    new_body.append(body.copy())
                except IndexError:
                    pass

        else:
            for idx in range(len(dates)):
                try:
                    """
                    If the detail level is low, medium or high
                    reduce end day by one to prevent duplications.
                    """
                    body.update(
                        {
                            "startDate": dates[idx],
                            "endDate": (
                                datetime.strptime(dates[idx + 1], "%Y-%m-%d")
                                - timedelta(days=1)
                            ).strftime("%Y-%m-%d"),
                        }
                    )
                    new_body.append(body.copy())
                except IndexError:
                    pass
    else:
        for date in dates:
            body.update({"startDate": date, "endDate": date})
            new_body.append(body.copy())

    return new_body


def path_exists(filename: str) -> bool:
    """
    Checks for the given file path exists.
    """
    from pathlib import Path

    return Path(filename).exists()


def regenerate_credentials(method):
    """
    If query raises RefreshError(Expired token causes this.)
    It automatically regenerate credentials
    and runs the method again.
    """

    def run_query(*args, **kw):
        try:
            result = method(*args, **kw)
        except RefreshError:
            regen = (
                typer.confirm(
                    "Your credentials has expired, do you want to regenerate them?",
                ),
            )

            if regen is True:
                auth.get_authenticated()
                typer.secho(
                    "Authenticated successfully!",
                    fg=typer.colors.BRIGHT_GREEN,
                    bold=True,
                ),
                result = method(*args, **kw)
            else:
                msg = typer.secho("Aborting...", bold=True, fg=typer.colors.BRIGHT_RED,)
                exit()

        return result

    return run_query
